Initial import of ripit version 1.2.

A perl-script frontend for encoding audio CDs to MP3 files.

PR:		11451
Submitted by:	Oscar Bonilla <obonilla@fisicc-ufm.edu>
This commit is contained in:
Steve Price 1999-05-03 03:52:22 +00:00
parent a9191d6a89
commit 95bd0a5ec0
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=18391
6 changed files with 80 additions and 0 deletions

25
audio/ripit/Makefile Normal file
View file

@ -0,0 +1,25 @@
# New ports collection makefile for: ripit
# Version required: 1.2
# Date created: 2 May 1999
# Whom: oyvindmo@initio.no
#
# $Id$
#
DISTNAME= ripit-1.2
CATEGORIES= audio
MASTER_SITES= http://www.netcomuk.co.uk/~squinn/
MAINTAINER= oyvindmo@initio.no
RUN_DEPENDS= bladeenc:${PORTSDIR}/audio/bladeenc \
tosha:${PORTSDIR}/audio/tosha \
cda:${PORTSDIR}/audio/xmcd
NO_BUILD= yes
USE_PERL5= yes
do-install:
@ ${INSTALL_SCRIPT} ${WRKSRC}/ripit.pl ${PREFIX}/bin
.include <bsd.port.mk>

1
audio/ripit/distinfo Normal file
View file

@ -0,0 +1 @@
MD5 (ripit-1.2.tar.gz) = a760057cd7a9b6d7bab4e911af5cc3a2

View file

@ -0,0 +1,41 @@
diff -uNr ../ripit-1.2.old/ripit.pl ./ripit.pl
--- ../ripit-1.2.old/ripit.pl Sun May 2 18:24:11 1999
+++ ./ripit.pl Sun May 2 18:27:10 1999
@@ -26,8 +26,8 @@
# User configurable variables
#
-$cddev = "/dev/cdrom"; # CD Audio device
-$outputdir = "/dosc/cdrip/"; # Where the MP3s should go
+$cddev = "/dev/rcd0c"; # CD Audio device
+$outputdir = "/home/mp3/"; # Where the MP3s should go
$bitrate = 160; # Bitrate for MP3s
$use_underscore = 0; # Use _ instead of spaces in filenames (1 yes, 0 no)
@@ -312,14 +312,11 @@
&printflush(RIPLOG,"Ripping $tracklist[$_ - 1]...\n");
- if (system("cdparanoia -d $cddev $riptrackno \"$riptrackname.rip\"")) {
- &printflush(RIPLOG,"cdparanoia failed on $tracklist[$_ - 1]\n");
- die "cdparanoia failed on $tracklist[$_ - 1]";
+ if (system("tosha -d $cddev -f wav -t $riptrackno -o \"$riptrackname.wav\"")) {
+ &printflush(RIPLOG,"tosha failed on $tracklist[$_ - 1]\n");
+ die "tosha failed on $tracklist[$_ - 1]";
}
- # Rename rip file to a wav so bladeenc will encode it
- rename "$riptrackname.rip","$riptrackname.wav";
-
&printflush(RIPLOG,"Rip complete $tracklist[$_ - 1]\n");
# Start the Encoder in the background. but only once
@@ -349,7 +346,7 @@
print "\nBladeenc Encoding track ".$ncount." of ".($#seltrack + 1)."\n";
&printflush(RIPLOG,"Encoding $tracklist[$_ - 1]...\n");
# Keep looping until the file appears, ie wait for cdparanoia
# timeout after 30 minutes
$x=0;
while( ! -r "$riptrackname.wav" ){

1
audio/ripit/pkg-comment Normal file
View file

@ -0,0 +1 @@
A perl-script frontend for encoding audio CDs to MP3 files.

11
audio/ripit/pkg-descr Normal file
View file

@ -0,0 +1,11 @@
ripit
-----
ripit is a small front-end program written in perl for ripping,
encoding & tagging MP3s. It is a console program that needs no user
intervention. It requires tosha, bladeenc and xmcd (for CDDB access).
@@ -349,7 +346,7 @@
print "\nBladeenc Encoding track ".$ncount." of ".($#seltrack + 1)."\n";
&printflush(RIPLOG,"Encoding $tracklist[$_ - 1]...\n");
- # Keep looping until the file appears, ie wait for cdparanoia
+ # Keep looping until the file appears, ie wait for tosha
# timeout after 30 minutes
$x=0;
http://www.netcomuk.co.uk/~squinn/ripit.html
--
Port by Oyvind Moll <oyvindmo@initio.no>

1
audio/ripit/pkg-plist Normal file
View file

@ -0,0 +1 @@
bin/ripit.pl